==> plugin.video.milionar.5.1.3.zip: plugin.video.milionar/.agent/skills/kodi-logic-core/SKILL.md <==
---
name: kodi-logic-core
description: Expert on Kodi Python API (xbmcgui), WindowXML lifecycle, and event handling. Use this for all Python scripts interacting with the GUI.
trigger: python_gui, windowxml, xbmcgui, event_handling, dialog_lifecycle
---

# Kodi Python Logic Core

## The WindowXML Lifecycle (CRITICAL)
You are operating in a specific runtime cycle. Do NOT confuse Python's `__init__` with Kodi's `onInit`.

* `__init__(self,...)`:
  * Status: XML is NOT loaded yet.
  * Allowed: Setting internal variables (`self.my_data = ...`).
  * FORBIDDEN: Calling `self.getControl()`. This will crash or return None.

* `onInit(self)`:
  * Status: XML is loaded, textures are ready.
  * Allowed: `self.getControl(ID)`, `self.list.addItems()`, `self.setFocus()`.
  * Warning: This method may be called multiple times if the skin reloads.

## Thread Safety Rules
The Kodi GUI is NOT thread-safe.
* NEVER modify UI elements (e.g., `setLabel`, `addItem`) from a background thread.
* Pattern: Fetch data in a thread → store in shared var → signal main thread → main thread updates UI.

## Event Handling
You must manually handle navigation and exit.
* Back Button: Check for action ID `92` (NAV_BACK) or `10` (PREV_MENU) in `onAction(self, action)`. If not checked, the user can get trapped.
* Memory Management: Always explicitly `del window_instance` after `.doModal()` returns to free C++ resources.

## Code Template (Safe Start)
```python
class MyWindow(xbmcgui.WindowXML):
    def onInit(self):
        # XML exists now. Safe to touch UI.
        self.list = self.getControl(50)
    
    def onAction(self, action):
        # ID 92 is NAV_BACK, 10 is PREVIOUS_MENU
        if action.getId() in [92, 10]:
            self.close()

==> plugin.video.milionar.8.0.3b.zip: plugin.video.milionar/.agent/skills/kodi-logic-core/SKILL.md <==
---
name: kodi-logic-core
description: Expert on Kodi Python API (xbmcgui), WindowXML lifecycle, and event handling. Use this for all Python scripts interacting with the GUI.
trigger: python_gui, windowxml, xbmcgui, event_handling, dialog_lifecycle
---

# Kodi Python Logic Core

## The WindowXML Lifecycle (CRITICAL)
You are operating in a specific runtime cycle. Do NOT confuse Python's `__init__` with Kodi's `onInit`.

* `__init__(self,...)`:
  * Status: XML is NOT loaded yet.
  * Allowed: Setting internal variables (`self.my_data = ...`).
  * FORBIDDEN: Calling `self.getControl()`. This will crash or return None.

* `onInit(self)`:
  * Status: XML is loaded, textures are ready.
  * Allowed: `self.getControl(ID)`, `self.list.addItems()`, `self.setFocus()`.
  * Warning: This method may be called multiple times if the skin reloads.

## File System Paths (CRITICAL)
Kodi uses virtual `special://` paths that Python's standard `os.path` and `open()` do NOT understand.

* **WRONG**: Using `addon.getAddonInfo('profile')` directly with `os.path.exists()` or `open()`.
* **RIGHT**: Always use `xbmcvfs.translatePath()` to convert to real filesystem path.

```python
import xbmcvfs
import xbmcaddon

# WRONG - os.path.exists() will fail with special:// paths
profile = xbmcaddon.Addon().getAddonInfo('profile')  # Returns "special://profile/addon_data/..."
os.path.exists(profile)  # Always False!

# RIGHT - translate first
profile = xbmcvfs.translatePath(xbmcaddon.Addon().getAddonInfo('profile'))
# Returns "/Users/.../Kodi/userdata/addon_data/..."
os.path.exists(profile)  # Works correctly
```

## Thread Safety Rules
The Kodi GUI is NOT thread-safe.
* NEVER modify UI elements (e.g., `setLabel`, `addItem`) from a background thread.
* Pattern: Fetch data in a thread → store in shared var → signal main thread → main thread updates UI.

## Event Handling
You must manually handle navigation and exit.
* Back Button: Check for action ID `92` (NAV_BACK) or `10` (PREV_MENU) in `onAction(self, action)`. If not checked, the user can get trapped.
* Memory Management: Always explicitly `del window_instance` after `.doModal()` returns to free C++ resources.

## Code Template (Safe Start)
```python
class MyWindow(xbmcgui.WindowXML):
    def onInit(self):
        # XML exists now. Safe to touch UI.
        self.list = self.getControl(50)
    
    def onAction(self, action):
        # ID 92 is NAV_BACK, 10 is PREVIOUS_MENU
        if action.getId() in [92, 10]:
            self.close()
